summaryrefslogtreecommitdiff
path: root/addons/base_import/static/src/js
diff options
context:
space:
mode:
authorqsm-odoo <qsm@odoo.com>2018-02-15 18:14:58 +0100
committerqsm-odoo <qsm@odoo.com>2018-04-18 15:59:18 +0200
commitfbfd0119041ca7dc830796e76d9ae5c303459d4f (patch)
treee30dd1a85988a97411a6d00945248fa1166cf465 /addons/base_import/static/src/js
parent97aa0a8dec384ad75eb66045f43384b6e54f1d6e (diff)
[REF] *: get rid of introduced @​extend
During first scss convertion, classes called as mixins were changed to an @​extend instruction which was the best approximation given the fact there is no equivalent in sass to do that. The problem is that the instruction is slowing the scss computation a lot and might also break the style in unexpected ways because of the complex unwanted selectors the instruction induces. This commit removes the need of extends. This is done case per case. Sometimes this involves adding classes in xml, sometimes to change the style a little, ... The button rendering refactoring which was made at the start of the LESS to SASS merge was also done in prevision of this. After this commit, sass computation is like 5-6 times faster than less computation while it was like 10 times *slower* before this commit.
Diffstat (limited to 'addons/base_import/static/src/js')
-rw-r--r--addons/base_import/static/src/js/import_action.js2
1 files changed, 1 insertions, 1 deletions
diff --git a/addons/base_import/static/src/js/import_action.js b/addons/base_import/static/src/js/import_action.js
index 1e17798ae34..d995e9cf055 100644
--- a/addons/base_import/static/src/js/import_action.js
+++ b/addons/base_import/static/src/js/import_action.js
@@ -281,7 +281,7 @@ var DataImport = AbstractAction.extend(ControlPanelMixin, {
// TODO: test that write // succeeded?
this.$el.removeClass('oe_import_preview_error oe_import_error');
this.$el.toggleClass(
- 'oe_import_noheaders',
+ 'oe_import_noheaders text-muted',
!this.$('input.oe_import_has_header').prop('checked'));
this._rpc({
model: 'base_import.import',